<?php

declare(strict_types=1);

namespace Drupal\layout_collapse\Plugin\LayoutOption;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\Xss;
use Drupal\layout_options\OptionBase;

/**
 * Layout Option plugin to add an data-layout-collapse-summary attribute.
 *
 * @LayoutOption(
 *     id = "layout_collapse_summary_data",
 *     label = @Translation("Summary Data Attribute option"),
 *     description = @Translation("A layout configuration option that adds a data-layout-collapse-summary attributes to layout and/or regions.")
 * )
 */
class SummaryDataAttributeOption extends OptionBase {

  /**
   * {@inheritdoc}
   */
  public function processFormOption(string $region, array $form, FormStateInterface $formState, $default): array {
    return $this->createTextElement($region, $form, $formState, $default);
  }

  /**
   * {@inheritdoc}
   */
  public function processOptionBuild(array $regions, array $build, string $region, $value): array {
    $markup = Xss::filter($value);
    return $this->processAttributeOptionBuild('data-layout-collapse-summary', $regions, $build, $region, $markup);
  }

}
